@@ -1,13 +1,15 @@
-# Copyright 2021-2022 Mufeed Ali
-# Copyright 2021-2022 Rafael Mardojai CM
+# Copyright 2021 Mufeed Ali
+# Copyright 2021 Rafael Mardojai CM
 # SPDX-License-Identifier: GPL-3.0-or-later
 
+from typing import Callable
+
 from gi.repository import Gio, GObject
 
 from dialect.define import LANGUAGES
 
 
-def get_lang_name(code):
+def get_lang_name(code: str) -> str | None:
     name = LANGUAGES.get(code)
     if name:
         name = gettext(name)
@@ -17,43 +19,43 @@ def get_lang_name(code):
 class LangObject(GObject.Object):
     __gtype_name__ = "LangObject"
 
-    code = GObject.Property(type=str)
-    name = GObject.Property(type=str)
-    selected = GObject.Property(type=bool, default=False)
+    code: str = GObject.Property(type=str)  # type: ignore
+    name: str = GObject.Property(type=str)  # type: ignore
+    selected: bool = GObject.Property(type=bool, default=False)  # type: ignore
 
-    def __init__(self, code, name, selected=False):
+    def __init__(self, code: str, name: str, selected=False):
         super().__init__()
 
         self.code = code
         self.name = name
         self.selected = selected
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.code
 
 
 class LanguagesListModel(GObject.GObject, Gio.ListModel):
     __gtype_name__ = "LanguagesListModel"
 
-    def __init__(self, names_func=get_lang_name):
+    def __init__(self, names_func: Callable[[str], str | None] = get_lang_name):
         super().__init__()
 
         self.names_func = names_func
-        self.langs = []
+        self.langs: list[LangObject] = []
 
     def __iter__(self):
         return iter(self.langs)
 
-    def do_get_item(self, position):
+    def do_get_item(self, position: int) -> LangObject:
         return self.langs[position]
 
     def do_get_item_type(self):
         return LangObject
 
-    def do_get_n_items(self):
+    def do_get_n_items(self) -> int:
         return len(self.langs)
 
-    def set_langs(self, langs, auto=False):
+    def set_langs(self, langs: list[str], auto=False):
         removed = len(self.langs)
         self.langs.clear()
 
@@ -61,10 +63,10 @@ class LanguagesListModel(GObject.GObject, Gio.ListModel):
             self.langs.append(LangObject("auto", _("Auto")))
 
         for code in langs:
-            self.langs.append(LangObject(code, self.names_func(code)))
+            self.langs.append(LangObject(code, self.names_func(code) or code))
 
         self.items_changed(0, removed, len(self.langs))
 
-    def set_selected(self, code):
+    def set_selected(self, code: str):
         for item in self.langs:
             item.props.selected = item.code == code
